summaryrefslogtreecommitdiffstats
path: root/kate/part/kateviewhelpers.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kate/part/kateviewhelpers.cpp
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kate/part/kateviewhelpers.cpp')
-rw-r--r--kate/part/kateviewhelpers.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kate/part/kateviewhelpers.cpp b/kate/part/kateviewhelpers.cpp
index da88676bc..663255714 100644
--- a/kate/part/kateviewhelpers.cpp
+++ b/kate/part/kateviewhelpers.cpp
@@ -170,7 +170,7 @@ void KateScrollBar::recomputeMarksPositions(bool forceFullUpdate)
if (tree)
{
- KateCodeFoldingNode *node = tree->findNodeForLine(line);
+ KateCodeFoldingNode *node = tree->tqfindNodeForLine(line);
while (node)
{
@@ -244,7 +244,7 @@ class KateCmdLnWhatsThis : public QWhatsThis
Kate::Command *cmd = KateCmd::self()->queryCommand( name );
if ( cmd )
{
- if ( cmd->help( (Kate::View*)m_parent->parentWidget(), name, s ) )
+ if ( cmd->help( (Kate::View*)m_parent->tqparentWidget(), name, s ) )
return beg + name + mid + s + end;
else
return beg + name + mid + i18n("No help for '%1'").arg( name ) + end;
@@ -380,7 +380,7 @@ void KateCmdLine::slotReturnPressed ( const TQString& text )
void KateCmdLine::hideMe () // unless i have focus ;)
{
- if ( isVisibleTo(parentWidget()) && ! hasFocus() ) {
+ if ( isVisibleTo(tqparentWidget()) && ! hasFocus() ) {
m_view->toggleCmdLine ();
}
}
@@ -697,7 +697,7 @@ KateIconBorder::KateIconBorder ( KateViewInternal* internalView, TQWidget *paren
, m_cachedLNWidth( 0 )
, m_maxCharWidth( 0 )
{
- setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Minimum ) );
+ tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Minimum ) );
setBackgroundMode( NoBackground );
@@ -757,7 +757,7 @@ void KateIconBorder::setFoldingMarkersOn( bool enable )
TQTimer::singleShot( 0, this, TQT_SLOT(update()) );
}
-TQSize KateIconBorder::sizeHint() const
+TQSize KateIconBorder::tqsizeHint() const
{
int w = 0;
@@ -866,7 +866,7 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
{
// we went from n0 ->n9 lines or vice verca
// this causes an extra updateGeometry() first time the line numbers
// are displayed, but sizeHint() is supposed to be const so we can't set
// the cached value there.
m_cachedLNWidth = lnWidth;
m_oldBackgroundColor = m_view->renderer()->config()->iconBarColor();
@@ -1202,4 +1202,4 @@ void KateViewEncodingAction::setMode (int mode)
doc->reloadFile();
}
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
@@ -866,7 +866,7 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
// we went from n0 ->n9 lines or vice verca
// this causes an extra updateGeometry() first time the line numbers
- // are displayed, but sizeHint() is supposed to be const so we can't set
+ // are displayed, but tqsizeHint() is supposed to be const so we can't set
// the cached value there.
m_cachedLNWidth = lnWidth;